==> gmssl-sdf-crypto-1.0.0-20191119.103842-1-sources.jar: com/xdja/pki/gmssl/crypto/sdf/SdfContentSigner.java <==
package com.xdja.pki.gmssl.crypto.sdf;

import com.xdja.pki.gmssl.sdf.SdfSDKException;
import org.bouncycastle.asn1.gm.GMObjectIdentifiers;
import org.bouncycastle.asn1.x509.AlgorithmIdentifier;
import org.bouncycastle.crypto.params.AsymmetricKeyParameter;
import org.bouncycastle.operator.ContentSigner;
import org.bouncycastle.operator.RuntimeOperatorException;

import java.io.OutputStream;
import java.security.SignatureException;
import java.security.interfaces.ECPublicKey;
import java.security.interfaces.RSAPublicKey;

public class SdfContentSigner implements ContentSigner {

    private SdfContentOutputStream stream;
    private AlgorithmIdentifier algorithmIdentifier;

    public SdfContentSigner(SdfCryptoType sdfCryptoType, AlgorithmIdentifier algorithmIdentifier, SdfPrivateKey privateKey) throws SdfSDKException {
        this.algorithmIdentifier = algorithmIdentifier;
        AsymmetricKeyParameter asymmetricKeyParameter = null;
        if (SdfSHAType.checkSupportType(algorithmIdentifier.getAlgorithm())) {
            asymmetricKeyParameter = new SdfRSAKeyParameters(privateKey);
        } else if (GMObjectIdentifiers.sm2sign_with_sm3.getId().equals(algorithmIdentifier.getAlgorithm().getId())) {
            asymmetricKeyParameter = new SdfECKeyParameters(privateKey);
        } else {
            throw new SdfSDKException("UnSupport algorithmIdentifier: " + algorithmIdentifier.getAlgorithm().getId());
        }
        this.stream = new SdfContentOutputStream(sdfCryptoType, algorithmIdentifier, true, asymmetricKeyParameter);
    }

    @Override
    public AlgorithmIdentifier getAlgorithmIdentifier() {
        return this.algorithmIdentifier;
    }

    @Override
    public OutputStream getOutputStream() {
        return this.stream;
    }

    @Override
    public byte[] getSignature() {
        try {
            return this.stream.getSignature();
        } catch (SignatureException e) {
            throw new RuntimeOperatorException("exception obtaining signature: " + e.getMessage(), e);
        }
    }
}

==> gmssl-sdf-crypto-1.0.4-20210913.133012-13-sources.jar: com/xdja/pki/gmssl/crypto/sdf/SdfContentSigner.java <==
package com.xdja.pki.gmssl.crypto.sdf;

import com.xdja.pki.gmssl.sdf.SdfSDKException;
import org.bouncycastle.asn1.gm.GMObjectIdentifiers;
import org.bouncycastle.asn1.x509.AlgorithmIdentifier;
import org.bouncycastle.asn1.x9.X9ObjectIdentifiers;
import org.bouncycastle.crypto.params.AsymmetricKeyParameter;
import org.bouncycastle.operator.ContentSigner;
import org.bouncycastle.operator.RuntimeOperatorException;

import java.io.OutputStream;
import java.security.SignatureException;
import java.security.interfaces.ECPublicKey;
import java.security.interfaces.RSAPublicKey;

public class SdfContentSigner implements ContentSigner {

    private SdfContentOutputStream stream;
    private AlgorithmIdentifier algorithmIdentifier;

    public SdfContentSigner(SdfCryptoType sdfCryptoType, AlgorithmIdentifier algorithmIdentifier, SdfPrivateKey privateKey) throws SdfSDKException {
        this(sdfCryptoType, algorithmIdentifier, privateKey, Constants.SDF_SM2_USED_BC_SM3);
    }

    public SdfContentSigner(SdfCryptoType sdfCryptoType, AlgorithmIdentifier algorithmIdentifier, SdfPrivateKey privateKey, boolean useBC) throws SdfSDKException {
        this.algorithmIdentifier = algorithmIdentifier;
        AsymmetricKeyParameter asymmetricKeyParameter = null;
        if (SdfSHAType.checkSupportType(algorithmIdentifier.getAlgorithm())) {
            asymmetricKeyParameter = new SdfRSAKeyParameters(privateKey);
        } else if (GMObjectIdentifiers.sm2sign_with_sm3.getId().equals(algorithmIdentifier.getAlgorithm().getId())) {
            asymmetricKeyParameter = new SdfECKeyParameters(privateKey);
        } else if( X9ObjectIdentifiers.ecdsa_with_SHA256.getId().equals(algorithmIdentifier.getAlgorithm().getId())){
            asymmetricKeyParameter = new SdfECKeyParameters(privateKey);
        }else {
            throw new SdfSDKException("UnSupport algorithmIdentifier: " + algorithmIdentifier.getAlgorithm().getId());
        }
        this.stream = new SdfContentOutputStream(sdfCryptoType, algorithmIdentifier, true, asymmetricKeyParameter, useBC);
    }

    @Override
    public AlgorithmIdentifier getAlgorithmIdentifier() {
        return this.algorithmIdentifier;
    }

    @Override
    public OutputStream getOutputStream() {
        return this.stream;
    }

    @Override
    public byte[] getSignature() {
        try {
            return this.stream.getSignature();
        } catch (SignatureException e) {
            throw new RuntimeOperatorException("exception obtaining signature: " + e.getMessage(), e);
        }
    }
}
